@@ -658,8 +658,7 @@ gedit_notebook_init (GeditNotebook *notebook)
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
 
 	notebook->priv->title_tips = gedit_tooltips_new ();
-	g_object_ref (G_OBJECT (notebook->priv->title_tips));
-	gtk_object_sink (GTK_OBJECT (notebook->priv->title_tips));
+	g_object_ref_sink (notebook->priv->title_tips);
 
 	notebook->priv->always_show_tabs = TRUE;
 
@@ -780,6 +779,21 @@ close_button_clicked_cb (GtkWidget *widget,
 	g_signal_emit (notebook, signals[TAB_CLOSE_REQUEST], 0, tab);
 }
 
+static void
+tab_label_style_set_cb (GtkWidget *hbox,
+			GtkStyle *previous_style,
+			gpointer user_data)
+{
+	GtkWidget *button;
+	gint h, w;
+
+	gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (hbox),
+					   GTK_ICON_SIZE_MENU, &w, &h);
+
+	button = g_object_get_data (G_OBJECT (hbox), "close-button");
+	gtk_widget_set_size_request (button, w + 2, h + 2);
+}
+
 static GtkWidget *
 build_tab_label (GeditNotebook *nb, 
 		 GeditTab      *tab)
@@ -787,19 +801,18 @@ build_tab_label (GeditNotebook *nb,
 	GtkWidget *hbox, *label_hbox, *label_ebox;
 	GtkWidget *label, *dummy_label;
 	GtkWidget *close_button;
-	GtkSettings *settings;
-	gint w, h;
+	GtkRcStyle *rcstyle;
 	GtkWidget *image;
 	GtkWidget *spinner;
 	GtkWidget *icon;
 
-	hbox = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_hbox_new (FALSE, 4);
 
 	label_ebox = gtk_event_box_new ();
 	gtk_event_box_set_visible_window (GTK_EVENT_BOX (label_ebox), FALSE);
 	gtk_box_pack_start (GTK_BOX (hbox), label_ebox, TRUE, TRUE, 0);
 
-	label_hbox = gtk_hbox_new (FALSE, 0);
+	label_hbox = gtk_hbox_new (FALSE, 4);
 	gtk_container_add (GTK_CONTAINER (label_ebox), label_hbox);
 
 	/* setup close button */
@@ -809,22 +822,24 @@ build_tab_label (GeditNotebook *nb,
 	/* don't allow focus on the close button */
 	gtk_button_set_focus_on_click (GTK_BUTTON (close_button), FALSE);
 
-	/* fetch the size of an icon */
-	settings = gtk_widget_get_settings (GTK_WIDGET (tab));
-	gtk_icon_size_lookup_for_settings (settings,
-					   GTK_ICON_SIZE_MENU,
-					   &w, &h);
-	image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
-	gtk_widget_set_size_request (close_button, w + 2, h + 2);
+	/* make it as small as possible */
+	rcstyle = gtk_rc_style_new ();
+	rcstyle->xthickness = rcstyle->ythickness = 0;
+	gtk_widget_modify_style (close_button, rcstyle);
+	gtk_rc_style_unref (rcstyle),
+
+	image = gtk_image_new_from_stock (GTK_STOCK_CLOSE,
+					  GTK_ICON_SIZE_MENU);
 	gtk_container_add (GTK_CONTAINER (close_button), image);
 	gtk_box_pack_start (GTK_BOX (hbox), close_button, FALSE, FALSE, 0);
 
 	gedit_tooltips_set_tip (nb->priv->title_tips, close_button,
 			      _("Close document"), NULL);
 
-	g_signal_connect (G_OBJECT (close_button), "clicked",
-                          G_CALLBACK (close_button_clicked_cb),
-                          tab);
+	g_signal_connect (close_button,
+			  "clicked",
+			  G_CALLBACK (close_button_clicked_cb),
+			  tab);
 
 	/* setup spinner */
 	spinner = gedit_spinner_new ();
@@ -836,14 +851,18 @@ build_tab_label (GeditNotebook *nb,
 	gtk_box_pack_start (GTK_BOX (label_hbox), icon, FALSE, FALSE, 0);
 	
 	/* setup label */
-        label = gtk_label_new ("");
+	label = gtk_label_new ("");
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-        gtk_misc_set_padding (GTK_MISC (label), 2, 0);
+	gtk_misc_set_padding (GTK_MISC (label), 0, 0);
 	gtk_box_pack_start (GTK_BOX (label_hbox), label, FALSE, FALSE, 0);
 
 	dummy_label = gtk_label_new ("");
 	gtk_box_pack_start (GTK_BOX (label_hbox), dummy_label, TRUE, TRUE, 0);
 	
+	/* Set minimal size */
+	g_signal_connect (hbox, "style-set",
+			  G_CALLBACK (tab_label_style_set_cb), NULL);
+	
 	gtk_widget_show (hbox);
 	gtk_widget_show (label_ebox);
 	gtk_widget_show (label_hbox);
