@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-plugin.h,v 1.12 2006/01/06 16:45:20 pborelli Exp $
+ * $Id: gedit-plugin.h,v 1.13 2006/07/17 16:50:56 jessevdk Exp $
  */
 
 #ifndef __GEDIT_PLUGIN_H__
@@ -34,6 +34,7 @@
 #include <glib-object.h>
 
 #include <gedit/gedit-window.h>
+#include <gedit/gedit-debug.h>
 
 /* TODO: add a .h file that includes all the .h files normally needed to
  * develop a plugin */ 
@@ -115,10 +116,9 @@ GtkWidget	*gedit_plugin_create_configure_dialog
 /*
  * Utility macro used to register plugins
  *
- * use: GEDIT_PLUGIN_REGISTER_TYPE(GeditSamplePlugin, gedit_sample_plugin)
+ * use: GEDIT_PLUGIN_REGISTER_TYPE_WITH_CODE(PluginName, plugin_name, CODE)
  */
-
-#define GEDIT_PLUGIN_REGISTER_TYPE(PluginName, plugin_name)			\
+#define GEDIT_PLUGIN_REGISTER_TYPE_WITH_CODE(PluginName, plugin_name, CODE)	\
 										\
 static GType plugin_name##_type = 0;						\
 										\
@@ -164,9 +164,80 @@ register_gedit_plugin (GTypeModule *module)					\
 					    #PluginName,			\
 					    &our_info,				\
 					    0);					\
+										\
+	CODE									\
+										\
 	return plugin_name##_type;						\
 }
 
+/*
+ * Utility macro used to register plugins
+ *
+ * use: GEDIT_PLUGIN_REGISTER_TYPE(PluginName, plugin_name)
+ */
+#define GEDIT_PLUGIN_REGISTER_TYPE(PluginName, plugin_name)			\
+	GEDIT_PLUGIN_REGISTER_TYPE_WITH_CODE(PluginName, plugin_name, ;)
+
+/*
+ * Utility macro used to register gobject types in plugins with additional code
+ *
+ * use: GEDIT_PLUGIN_DEFINE_TYPE_WITH_CODE(ObjectName, object_name, PARENT_TYPE, CODE)
+ */
+#define GEDIT_PLUGIN_DEFINE_TYPE_WITH_CODE(ObjectName, object_name, PARENT_TYPE, CODE)	\
+										\
+static GType g_define_type_id = 0;						\
+										\
+GType										\
+object_name##_get_type (void)							\
+{										\
+	return g_define_type_id;						\
+}										\
+										\
+static void     object_name##_init              (ObjectName        *self);	\
+static void     object_name##_class_init        (ObjectName##Class *klass);	\
+static gpointer object_name##_parent_class = NULL;				\
+static void     object_name##_class_intern_init (gpointer klass)		\
+{										\
+	object_name##_parent_class = g_type_class_peek_parent (klass);		\
+	object_name##_class_init ((ObjectName##Class *) klass);			\
+}										\
+										\
+GType										\
+object_name##_register_type (GTypeModule *module)					\
+{										\
+	static const GTypeInfo our_info =					\
+	{									\
+		sizeof (ObjectName##Class),					\
+		NULL, /* base_init */						\
+		NULL, /* base_finalize */					\
+		(GClassInitFunc) object_name##_class_intern_init,		\
+		NULL,								\
+		NULL, /* class_data */						\
+		sizeof (ObjectName),						\
+		0, /* n_preallocs */						\
+		(GInstanceInitFunc) object_name##_init				\
+	};									\
+										\
+	gedit_debug_message (DEBUG_PLUGINS, "Registering " #ObjectName);	\
+										\
+	g_define_type_id = g_type_module_register_type (module,			\
+					   	        PARENT_TYPE,		\
+					                #ObjectName,		\
+					                &our_info,		\
+					                0);			\
+										\
+	CODE									\
+										\
+	return g_define_type_id;						\
+}
+
+/*
+ * Utility macro used to register gobject types in plugins
+ *
+ * use: GEDIT_PLUGIN_DEFINE_TYPE(ObjectName, object_name, PARENT_TYPE)
+ */
+#define GEDIT_PLUGIN_DEFINE_TYPE(ObjectName, object_name, PARENT_TYPE)		\
+	GEDIT_PLUGIN_DEFINE_TYPE_WITH_CODE(ObjectName, object_name, PARENT_TYPE, ;)
 
 G_END_DECLS
 
