@@ -26,7 +26,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-prefs-manager-app.c,v 1.16 2006/09/23 14:37:09 pborelli Exp $
+ * $Id: gedit-prefs-manager-app.c,v 1.17 2006/10/08 14:26:02 pborelli Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -291,7 +291,7 @@ gedit_prefs_manager_get_default_window_size (gint *width, gint *height)
 	g_return_if_fail (width != NULL && height != NULL);
 
 	*width = GPM_DEFAULT_WINDOW_WIDTH;
-	*height = GPM_DEFAULT_WINDOW_HEIGHT;;
+	*height = GPM_DEFAULT_WINDOW_HEIGHT;
 }
 
 void
