@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-window.c,v 1.38 2006/08/26 15:06:00 pborelli Exp $
+ * $Id: gedit-window.c,v 1.41 2006/10/14 10:32:57 pborelli Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -168,11 +168,9 @@ gedit_window_finalize (GObject *object)
 }
 
 static void
-gedit_window_destroy (GtkObject *object)
+save_panes_state (GeditWindow *window)
 {
-	GeditWindow *window;
-
-	window = GEDIT_WINDOW (object);
+	gint pane_page;
 
 	if (gedit_prefs_manager_window_size_can_set ())
 		gedit_prefs_manager_set_window_size (window->priv->width,
@@ -182,15 +180,40 @@ gedit_window_destroy (GtkObject *object)
 		gedit_prefs_manager_set_window_state (window->priv->window_state);
 
 	if ((window->priv->side_panel_size > 0) &&
-		gedit_prefs_manager_side_panel_size_can_set ())
-			gedit_prefs_manager_set_side_panel_size	(
+	    gedit_prefs_manager_side_panel_size_can_set ())
+		gedit_prefs_manager_set_side_panel_size	(
 					window->priv->side_panel_size);
 
+	pane_page = _gedit_panel_get_active_item_id (GEDIT_PANEL (window->priv->side_panel));
+	if (pane_page != 0 &&
+	    gedit_prefs_manager_side_panel_active_page_can_set ())
+		gedit_prefs_manager_set_side_panel_active_page (pane_page);
+
 	if ((window->priv->bottom_panel_size > 0) && 
-		gedit_prefs_manager_bottom_panel_size_can_set ())
-			gedit_prefs_manager_set_bottom_panel_size (
+	    gedit_prefs_manager_bottom_panel_size_can_set ())
+		gedit_prefs_manager_set_bottom_panel_size (
 					window->priv->bottom_panel_size);
 
+	pane_page = _gedit_panel_get_active_item_id (GEDIT_PANEL (window->priv->bottom_panel));
+	if (pane_page != 0 &&
+	    gedit_prefs_manager_bottom_panel_active_page_can_set ())
+		gedit_prefs_manager_set_bottom_panel_active_page (pane_page);
+}
+
+static void
+gedit_window_destroy (GtkObject *object)
+{
+	GeditWindow *window;
+	gint pane_page;
+
+	window = GEDIT_WINDOW (object);
+
+	if (!window->priv->destroy_has_run)
+	{
+		save_panes_state (window);
+		window->priv->destroy_has_run = TRUE;
+	}
+
 	GTK_OBJECT_CLASS (gedit_window_parent_class)->destroy (object);
 }
 
@@ -2067,11 +2090,12 @@ update_window_state (GeditWindow *window)
 						  window->priv->state,
 						  window->priv->num_tabs_with_error);	
 	}
-	
 }
 
 static void
-sync_state (GeditTab *tab, GParamSpec *pspec, GeditWindow *window)
+sync_state (GeditTab    *tab,
+	    GParamSpec  *pspec,
+	    GeditWindow *window)
 {
 	gedit_debug (DEBUG_WINDOW);
 	
@@ -2086,7 +2110,9 @@ sync_state (GeditTab *tab, GParamSpec *pspec, GeditWindow *window)
 }
 
 static void
-sync_name (GeditTab *tab, GParamSpec *pspec, GeditWindow *window)
+sync_name (GeditTab    *tab,
+	   GParamSpec  *pspec,
+	   GeditWindow *window)
 {
 	GtkAction *action;
 	gchar *action_name;
@@ -2096,10 +2122,16 @@ sync_name (GeditTab *tab, GParamSpec *pspec, GeditWindow *window)
 	gint n;
 	GeditDocument *doc;
 
-	if (tab != window->priv->active_tab)
-		return;
+	if (tab == window->priv->active_tab)
+	{
+		set_title (window);
 
-	set_title (window);
+		doc = gedit_tab_get_document (tab);
+		action = gtk_action_group_get_action (window->priv->action_group,
+						      "FileRevert");
+		gtk_action_set_sensitive (action,
+					  !gedit_document_is_untitled (doc));
+	}
 
 	/* sync the item in the documents list menu */
 	n = gtk_notebook_page_num (GTK_NOTEBOOK (window->priv->notebook),
@@ -2121,12 +2153,6 @@ sync_name (GeditTab *tab, GParamSpec *pspec, GeditWindow *window)
 	g_free (escaped_name);
 	g_free (tip);
 
-	doc = gedit_tab_get_document (tab);
-	action = gtk_action_group_get_action (window->priv->action_group,
-					      "FileRevert");
-	gtk_action_set_sensitive (action,
-				  !gedit_document_is_untitled (doc));
-
 	gedit_plugins_engine_update_plugins_ui (window, FALSE);
 }
 
@@ -2992,15 +3018,25 @@ create_bottom_panel (GeditWindow *window)
 static void
 init_panels_visibility (GeditWindow *window)
 {
+	gint active_page;
+
 	gedit_debug (DEBUG_WINDOW);
 
 	/* side pane */
+	active_page = gedit_prefs_manager_get_side_panel_active_page ();
+	_gedit_panel_set_active_item_by_id (GEDIT_PANEL (window->priv->side_panel),
+					    active_page);
+
 	if (gedit_prefs_manager_get_side_pane_visible ())
 		gtk_widget_show (window->priv->side_panel);
 
 	/* bottom pane, it can be empty */
 	if (gedit_panel_get_n_items (GEDIT_PANEL (window->priv->bottom_panel)) > 0)
 	{
+		active_page = gedit_prefs_manager_get_bottom_panel_active_page ();
+		_gedit_panel_set_active_item_by_id (GEDIT_PANEL (window->priv->bottom_panel),
+						    active_page);
+
 		if (gedit_prefs_manager_get_bottom_panel_visible ())
   			gtk_widget_show (window->priv->bottom_panel);
 	}
@@ -3036,6 +3072,7 @@ gedit_window_init (GeditWindow *window)
 	window->priv->num_tabs = 0;
 	window->priv->removing_tabs = FALSE;
 	window->priv->state = GEDIT_WINDOW_STATE_NORMAL;
+	window->priv->destroy_has_run = FALSE;
 
 	window->priv->window_group = gtk_window_group_new ();
 	gtk_window_group_add_window (window->priv->window_group, GTK_WINDOW (window));
